@@ -1,7 +1,7 @@
 package App::tracepm::Tracer;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-01-18'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 # saving CORE::GLOBAL::require doesn't work
 my $orig_require;
@@ -12,6 +12,10 @@ sub import {
     # already installed
     return if $orig_require;
 
+    # doesn't mention any file, e.g. in 00-compile.t
+    my $file = shift
+        or return;
+
     my $opts = {
         workaround_log4perl => 1,
     };
@@ -19,8 +23,6 @@ sub import {
         $opts = shift;
     }
 
-    my $file = shift
-        or die "Usage: use App::tracerpm::Tracer '/path/to/output'";
 
     open my($fh), ($ENV{TRACEPM_TRACER_APPEND} ? ">>":">"),
         $file or die "Can't open $file: $!";
@@ -62,7 +64,7 @@ App::tracepm::Tracer - Trace module require to file
 
 =head1 VERSION
 
-This document describes version 0.18 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-09-03.
+This document describes version 0.19 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2016-01-18.
 
 =head1 HOMEPAGE
 
@@ -70,7 +72,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-tracep
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-tracepm>.
+Source repository is at L<https://github.com/sharyanto/perl-App-tracepm>.
 
 =head1 BUGS
 
@@ -86,7 +88,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
